@@ -42,16 +42,10 @@ sub os_deps {
       return ( 'VMS::Process' => 0 );
    }
    else {
-      # let's hope they have /proc
-      if ( -d '/proc' and @{[ glob('/proc/*') ]} ) {
-         return ();
-      }
-      # ...or that Proc::ProcessTable can handle it
-      else {
+      if ( not -d '/proc' ) {
          return ( 'Proc::ProcessTable' => 0.48 );  # ie: the one that ain't broke
       }
    }
-   return ();
 }
 TEMPLATE
 
