@@ -1,7 +1,6 @@
 package P9Y::ProcessTable;
 
-our $AUTHORITY = 'cpan:BBYRD'; # AUTHORITY
-our $VERSION = '1.06_01'; # VERSION
+our $VERSION = '1.05'; # VERSION
 # ABSTRACT: Portably access the process table
 
 use strict;
@@ -25,7 +24,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -205,6 +204,15 @@ support, dive into the C<<< ProcFS >>> code and submit a patch.
 
 =item *
 
+One would say that the class-based calling of ProcessTable (vs. the more traditional OO model of P9Y:PT:Process) is confusing.  I tend to agree,
+but it was modeled after Proc:PT's calling scheme.
+
+=back
+
+=over
+
+=item *
+
 See L<P9Y::ProcessTable::Process> for other caveats.
 
 =back
@@ -237,7 +245,7 @@ L<VMS::Process>
 
 =head1 AVAILABILITY
 
-The project homepage is L<https://github.com/SineSwiper/P9Y-ProcessTable>.
+The project homepage is L<https://github.com/SineSwiper/P9Y-ProcessTable/wiki>.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
@@ -270,7 +278,7 @@ Please report any bugs or feature requests via L<https://github.com/SineSwiper/P
 
 =head1 AUTHOR
 
-Brendan Byrd <BBYRD@CPAN.org>
+Brendan Byrd <bbyrd@cpan.org>
 
 =head1 CONTRIBUTORS
 
