@@ -1,7 +1,6 @@
 package P9Y::ProcessTable::Process;
 
-our $AUTHORITY = 'cpan:BBYRD'; # AUTHORITY
-our $VERSION = '1.06_01'; # VERSION
+our $VERSION = '1.05'; # VERSION
 # ABSTRACT: Base class for a single process
 
 #############################################################################
@@ -11,6 +10,7 @@ use strict;
 use warnings;
 
 use Module::Runtime ();
+use Path::Class ();
 
 use Moo;
 
@@ -36,7 +36,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -150,7 +150,7 @@ Until L<Win32::API> is L<fixed|https://github.com/bulk88/perl5-win32-api>, C<<<
 
 =head1 AVAILABILITY
 
-The project homepage is L<https://github.com/SineSwiper/P9Y-ProcessTable>.
+The project homepage is L<https://github.com/SineSwiper/P9Y-ProcessTable/wiki>.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
@@ -158,7 +158,21 @@ site near you, or see L<https://metacpan.org/module/P9Y::ProcessTable/>.
 
 =head1 AUTHOR
 
-Brendan Byrd <BBYRD@CPAN.org>
+Brendan Byrd <bbyrd@cpan.org>
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Chris 'BinGOs' Williams <chris@bingosnet.co.uk>
+
+=item *
+
+Mithun Ayachit <m0t0rbr3th@gmail.com>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
