@@ -1,7 +1,6 @@
 package P9Y::ProcessTable::Role::Table::OS::MSWin32;
 
-our $AUTHORITY = 'cpan:BBYRD'; # AUTHORITY
-our $VERSION = '1.06_01'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 #############################################################################
 # Modules
