@@ -1,7 +1,6 @@
 package P9Y::ProcessTable::Role::Table::PPT;
 
-our $AUTHORITY = 'cpan:BBYRD'; # AUTHORITY
-our $VERSION = '1.06_01'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 #############################################################################
 # Modules
@@ -45,15 +44,14 @@ sub list {
 }
 
 sub fields {
-   # sometimes an undef pops through
-   return grep { $_ } $pt->fields;
+   return $pt->fields;
 }
 
 sub _process_hash {
    my ($self, $pid) = @_;
    my $process = first { $_->pid == $pid } @{ $pt->table };
    return unless $process;
-   return $self->_convert_process($process);
+   return $self->_convert_process;
 }
 
 sub _convert_process {
@@ -68,7 +66,10 @@ sub _convert_process {
 
    foreach my $key ( $self->fields ) {
       my $old = $stat_loc->{$key} || $key;
-      my $item = eval { $process->$old() };
+
+      # Sigh, why give me a field I can't access?
+      my $item;
+      $item = $process->$old() if $process->can($old);
 
       $hash->{$key} = $item if defined $item;
    }
