@@ -1,7 +1,7 @@
-package P9Y::ProcessTable::Table::Base;
+package  # hide from PAUSE
+   P9Y::ProcessTable::Table::Base;
 
-our $AUTHORITY = 'cpan:BBYRD'; # AUTHORITY
-our $VERSION = '1.06_01'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 #############################################################################
 # Modules
